@@ -13,7 +13,7 @@ use PPIx::Regexp::Util qw{ __instance };
 use Scalar::Util qw{ looks_like_number refaddr };
 use Test::More 0.88;
 
-our $VERSION = '0.042';
+our $VERSION = '0.043';
 
 our @EXPORT_OK = qw{
     cache_count
@@ -367,10 +367,11 @@ sub _method_result {		## no critic (RequireArgUnpacking)
     my $safe;
     if ( defined $result ) {
 	($safe = $result) =~ s/([\\'])/\\$1/smxg;
+	$safe = "'$safe'";
     } else {
 	$safe = 'undef';
     }
-    @_ = ( $result, $expect, "$kind $nav $method '$safe'" );
+    @_ = ( $result, $expect, "$kind $nav $method $safe" );
     goto &is;
 }
 
