@@ -42,7 +42,7 @@ use Scalar::Util qw{ refaddr weaken };
 
 use PPIx::Regexp::Constant qw{ MINIMUM_PERL TOKEN_UNKNOWN };
 
-our $VERSION = '0.042';
+our $VERSION = '0.043';
 
 =head2 ancestor_of
 
@@ -444,7 +444,14 @@ sub nav {
 # defaults for attributes. It returns nothing.
 #
 # The arguments are hash references, which are taken in left-to-right
-# order, with the, with the first extant value being used.
+# order, with the, with the first extant value being used. Arguments
+# which are not hash references are ignored.
+#
+# With version 0.042_03, this is also the preferred place to
+# validate an object, and needs to be called from both
+# __PPIX_ELEM__rebless() and __PPIX_TOKEN__post_make(). All overrides of
+# this should call SUPER:: unless they REALLY know what they are doing,
+# and document what is going on.
 
 sub __impose_defaults {
     my ( $self, @args ) = @_;
@@ -462,9 +469,6 @@ sub __impose_defaults {
 # Bless into TOKEN_UNKNOWN, record error message, return 1.
 sub __error {
     my ( $self, $msg ) = @_;
-    $self->isa( 'PPIx::Token::Node' )
-	and confess 'Programming error - __error() must be overridden',
-	    ' for class ', ref $self;
     defined $msg
 	or $msg = 'Was ' . ref $self;
     $self->{error} = $msg;
@@ -478,6 +482,19 @@ sub __PPIX_LEXER__record_capture_number {
     return $number;
 }
 
+# Called by the lexer to rebless
+sub __PPIX_ELEM__rebless {
+    my ( $class, $self, %arg ) = @_;
+    $self ||= {};
+    bless $self, $class;
+    delete $self->{error};
+    $self->__impose_defaults( \%arg );
+    defined $self->{error}
+	and return 1;
+    delete $self->{error};
+    return 0;
+}
+
 sub DESTROY {
     $_[0]->_parent( undef );
     return;
