@@ -36,12 +36,13 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Element };
 
+use Carp;
 use List::Util qw{ max };
 use PPIx::Regexp::Constant qw{ MINIMUM_PERL };
 use PPIx::Regexp::Util qw{ __instance };
 use Scalar::Util qw{ refaddr };
 
-our $VERSION = '0.042';
+our $VERSION = '0.043';
 
 sub _new {
     my ( $class, @children ) = @_;
@@ -403,6 +404,13 @@ sub _nav {
     return ( $method => [ $inx ] );
 }
 
+sub __error {
+    my ( $self ) = @_;	# second argument unused
+    confess 'Programming error - __error() must be overridden',
+	' for class ', ref $self;
+}
+
+
 # Called by the lexer once it has done its worst to all the tokens.
 # Called as a method with no arguments. The return is the number of
 # parse failures discovered when finalizing.
