@@ -43,7 +43,7 @@ use Carp qw{ confess };
 
 use PPIx::Regexp::Constant qw{ RE_CAPTURE_NAME };
 
-our $VERSION = '0.042';
+our $VERSION = '0.043';
 
 use constant NAMED_CAPTURE =>
     qr{ \A \\? \? (?: P? < ( @{[ RE_CAPTURE_NAME ]} ) \\? > |
@@ -68,7 +68,8 @@ sub perl_version_introduced {
 }
 
 sub __PPIX_TOKEN__post_make {
-    my ( $self, $tokenizer ) = @_;
+    my ( $self, $tokenizer, $arg ) = @_;
+    $self->__impose_defaults( $arg );
     if ( $tokenizer ) {
 	foreach my $name ( $tokenizer->capture() ) {
 	    defined $name or next;
