@@ -65,9 +65,6 @@ C<< $elem->asserted( 'd' ) >> would return true, since in the absence of
 an explicit C<l> or C<u> this class considers the C<^> to explicitly
 assert C<d>.
 
-B<Note> that if this is retracted before Perl 5.14 is released, this
-support will disappear. See L<PPIx::Regexp/NOTICE> for some explanation.
-
 =head1 METHODS
 
 This class provides the following public methods. Methods not documented
@@ -89,7 +86,7 @@ use PPIx::Regexp::Constant qw{
     MODIFIER_GROUP_MATCH_SEMANTICS
 };
 
-our $VERSION = '0.042';
+our $VERSION = '0.043';
 
 # Define modifiers that are to be aggregated internally for ease of
 # computation.
@@ -312,7 +309,20 @@ sub __aggregate_modifiers {
 	# distinguish between s/.../.../e and s/.../.../ee. But the
 	# modifiers can be randomized (that is, /eie is the same as
 	# /eei), so we reorder the content first.
-	$content = join '', sort split qr{}smx, $content;
+
+	# The following line is WRONG because it ignores the
+	# significance of '-'. This bug was introduced in version 0.035,
+	# specifically by the change that handled multi-character
+	# modifiers.
+	# $content = join '', sort split qr{}smx, $content;
+	# The following is better because it re-orders the modifiers
+	# separately. It does not recognize multiple dashes as
+	# representing an error (though it could!), and modifiers that
+	# are both asserted and negated (e.g. '(?i-i:foo)') are simply
+	# considered to be negated (as Perl does as of 5.20.0).
+	$content = join '-',
+	    map { join '', sort split qr{}smx }
+	    split qr{-}smx, $content;
 	my $value = 1;
 	while ( $content =~ m/ ( ( [[:alpha:]-] ) \2* ) /smxg ) {
 	    if ( '-' eq $1 ) {
@@ -350,7 +360,8 @@ sub __PPIX_TOKEN__recognize {
 # After the token is made, figure out what it asserts or negates.
 
 sub __PPIX_TOKEN__post_make {
-    my ( $self, $tokenizer ) = @_;
+    my ( $self, $tokenizer, $arg ) = @_;
+    $self->__impose_defaults( $arg );
     defined $tokenizer
 	and $tokenizer->modifier_modify( $self->modifiers() );
     return;
