@@ -37,7 +37,7 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token };
 
-our $VERSION = '0.042';
+our $VERSION = '0.043';
 
 # Return true if the token can be quantified, and false otherwise
 sub can_be_quantified { return };
@@ -56,15 +56,19 @@ sub ordinal {
     return ord $self->content();
 }
 
+sub __impose_defaults {
+    my ( $self, @args ) = @_;
+    $self->SUPER::__impose_defaults( @args );
+    unless ( defined $self->{error} ) {
+	Carp::cluck( 'Making unknown token with no error message' );
+	$self->{error} = 'Unspecified error';
+    }
+    return;
+}
+
 sub __PPIX_TOKEN__post_make {
     my ( $self, $tokenizer, $arg ) = @_;
-    my $msg = $arg->{error};
-    use Carp;
-    defined $msg
-	or Carp::cluck( 'Making unknown token with no error message' );
-    defined $msg
-	or $msg = 'Unspecified error';
-    $self->{error} = $msg;
+    $self->__impose_defaults( $arg );
     return;
 }
 
